# Generated by Django 3.1.4 on 2020-12-06 18:59

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='LogEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('description', models.TextField(blank=True, null=True)),
                ('action', models.CharField(choices=[('release', 'RELEASE'), ('remove', 'REMOVE'), ('anticipate', 'ANTICIPATE'), ('improved', 'IMPROVED')], default='r', max_length=20)),
                ('version', models.CharField(blank=True, max_length=20, null=True)),
            ],
            options={
                'verbose_name': 'Log Entry',
                'verbose_name_plural': 'Log Entries',
                'ordering': ('-version',),
            },
        ),
        migrations.CreateModel(
            name='Changelog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('version', models.CharField(max_length=20)),
                ('title', models.CharField(default='', max_length=200)),
                ('description', models.TextField(blank=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('published', models.BooleanField(default=True)),
                ('items', models.ManyToManyField(related_name='changelog', to='changelogs.LogEntry')),
            ],
            options={
                'verbose_name': 'Changelog',
                'verbose_name_plural': 'Changelogs',
                'ordering': ('-created_at',),
            },
        ),
    ]
